/* eslint-disable react-hooks/exhaustive-deps */
import React, { useEffect, useState } from "react";
import { View, Text, useWindowDimensions } from "react-native";
import Modal from "react-native-modal";
import styles from "./styles";
import { Color } from "../../constants";
import { usePrevious } from "../../hooks";
import Button from "../Button";
import WizardSteps from "../WizardSteps";
const AsyncStepModal = ({ isVisible = false, loading = [], data, ProcessCompletedComponent, onClose, }) => {
    const [selectedIndex, setSelectedIndex] = useState(0);
    const [processCompleted, setProcessCompleted] = useState(false);
    const { width } = useWindowDimensions();
    const onNext = () => {
        if (selectedIndex < data.length - 1) {
            setSelectedIndex((index) => index + 1);
        }
        else {
            setProcessCompleted(true);
        }
    };
    const onModalHide = () => {
        setProcessCompleted(false);
        setSelectedIndex(0);
    };
    const Component = () => {
        if (processCompleted) {
            return (React.createElement(View, { style: styles.processCompletedContainer },
                React.createElement(Text, { style: styles.processCompletedText }, "Done!")));
        }
        return data[selectedIndex].component;
    };
    const Lottie = () => {
        if (data[selectedIndex].lottie) {
            if (!processCompleted) {
                return (React.createElement(View, { style: { alignItems: "center" } }, data[selectedIndex].lottie));
            }
            return (React.createElement(View, { style: { alignItems: "center" } }, ProcessCompletedComponent));
        }
        return null;
    };
    const prevLoading = usePrevious(loading);
    useEffect(() => {
        for (let i = 0; i < loading.length; i++) {
            if (prevLoading?.[i] && !loading[i]) {
                onNext();
            }
        }
    }, [prevLoading, loading]);
    return (React.createElement(Modal, { isVisible: isVisible, onModalHide: onModalHide },
        React.createElement(View, { style: styles.modalView },
            React.createElement(Lottie, null),
            React.createElement(WizardSteps, { selectedIndex: selectedIndex, numberOfSteps: data.length, onStepPress: setSelectedIndex, width: width - 20, marginHorizontal: 40, activeColor: Color.primary, inactiveColor: Color.lightGrey, processCompleted: processCompleted, showNumbers: false, showLoading: true }),
            React.createElement(Text, { style: styles.titleText }, processCompleted ? "Process Completed" : data[selectedIndex].title),
            React.createElement(Component, null),
            processCompleted && (React.createElement(Button, { label: "OK", onPress: onClose, backgroundColor: Color.primary, labelColor: Color.white, style: styles.topMargin })))));
};
export default AsyncStepModal;
//# sourceMappingURL=index.js.map