import BottomSheet, { BottomSheetBackdrop, BottomSheetView, } from "@gorhom/bottom-sheet";
import React, { useCallback, useEffect, useMemo, useRef } from "react";
import { Text, View, StyleSheet } from "react-native";
import { Portal } from "react-native-portalize";
import styles from "./styles";
import { Color } from "../../constants";
const BottomModal = ({ modalTitle = "", isVisible, snapPoints, onClose, children, }) => {
    const bottomSheetRef = useRef(null);
    const defaultSnapPoints = useMemo(() => ["25%", "50%"], []);
    const snapPointsToUse = snapPoints || defaultSnapPoints;
    useEffect(() => {
        if (isVisible) {
            bottomSheetRef.current?.expand();
        }
        else {
            bottomSheetRef.current?.close();
        }
    }, [isVisible]);
    const renderBackdrop = useCallback((props) => (React.createElement(BottomSheetBackdrop, { ...props, disappearsOnIndex: -1, appearsOnIndex: 0 })), []);
    return (React.createElement(Portal, null,
        React.createElement(BottomSheet, { ref: bottomSheetRef, snapPoints: snapPointsToUse, enablePanDownToClose: true, index: -1, backgroundStyle: styles.bottomSheet, onClose: onClose, backdropComponent: renderBackdrop },
            React.createElement(BottomSheetView, { style: { flex: 1 } },
                React.createElement(Text, { style: styles.modalTitle }, modalTitle),
                React.createElement(View, { style: {
                        height: StyleSheet.hairlineWidth,
                        backgroundColor: Color.grey,
                        marginTop: 15,
                    } }),
                children))));
};
export default BottomModal;
//# sourceMappingURL=index.js.map