import Icon from "@expo/vector-icons/Ionicons";
import React from "react";
import { View, Text } from "react-native";
import styles from "./styles";
import { usePasswordStrengthIndicator } from "./usePasswordStrengthIndicator";
import { Color } from "../../constants";
export { usePasswordStrengthIndicator };
const PasswordStrengthIndicator = ({ password, requirements }) => {
    const { requirementsArr, validRequirements, charactersRemainingLabel } = usePasswordStrengthIndicator({
        password,
        requirements,
    });
    return (React.createElement(View, { style: styles.root },
        React.createElement(View, { style: styles.indicators }, requirementsArr.map((req, idx) => {
            const [fieldName] = Object.keys(req).slice(-1);
            const reqName = Object.keys(requirementsArr[idx])[0];
            const isFirst = idx === 0;
            const isLast = idx === Object.keys(requirements).length - 1;
            const isFirstStyles = isFirst && { marginLeft: 0, marginRight: 4 };
            const isLastStyles = isLast && { marginRight: 0 };
            const isSelectedAndValid = reqName === fieldName && validRequirements[fieldName];
            const backgroundColor = isSelectedAndValid
                ? Color.success
                : Color.error;
            if (!req.length) {
                return (React.createElement(View, { key: idx, style: [
                        styles.indicator,
                        isFirstStyles,
                        isLastStyles,
                        { backgroundColor },
                    ] }));
            }
            return null;
        })),
        React.createElement(View, null,
            React.createElement(Text, { style: styles.charactersText }, charactersRemainingLabel),
            React.createElement(View, { style: styles.row }, requirementsArr.map((req, idx) => {
                const [fieldName] = Object.keys(req).slice(-1);
                const reqName = Object.keys(requirementsArr[idx])[0];
                const isSelectedAndValid = reqName === fieldName && validRequirements[fieldName];
                if (!req.length) {
                    return (React.createElement(View, { key: idx, style: styles.validationContainer },
                        React.createElement(View, { style: styles.row },
                            React.createElement(Icon, { name: isSelectedAndValid ? "checkmark" : "close", color: isSelectedAndValid ? Color.success : Color.error }),
                            React.createElement(Text, { style: styles.requirementText }, fieldName))));
                }
                return null;
            })))));
};
export default PasswordStrengthIndicator;
//# sourceMappingURL=index.js.map