import { useEffect, useState } from "react";
import { ERequirement } from "../types";
const regexUppercase = /[A-Z]/;
const regexLowercase = /[a-z]/;
const regexSymbol = /[!@#$%^&*(),.?":{}|<>]/;
const regexNumber = /\d/;
const defaultValidRequrements = {
    [ERequirement.Lowercase]: false,
    [ERequirement.Uppercase]: false,
    [ERequirement.Numbers]: false,
    [ERequirement.Symbols]: false,
};
export const usePasswordStrengthIndicator = ({ password, requirements, }) => {
    const [validRequirements, setValidRequirements] = useState(defaultValidRequrements);
    const charactersRemaining = max(0, Number(requirements.length) - password.length);
    const charactersRemainingLabel = `${charactersRemaining} characters remaining`;
    const requirementsArr = Object.entries(requirements).map(([prop, value]) => ({
        [prop]: value,
    }));
    const validatePassword = (password, requirements) => {
        const validRequirements = {
            [ERequirement.Lowercase]: false,
            [ERequirement.Uppercase]: false,
            [ERequirement.Numbers]: false,
            [ERequirement.Symbols]: false,
        };
        if (requirements.lowercase) {
            validRequirements.lowercase = regexLowercase.test(password);
        }
        if (requirements.uppercase) {
            validRequirements.uppercase = regexUppercase.test(password);
        }
        if (requirements.numbers) {
            validRequirements.numbers = regexNumber.test(password);
        }
        if (requirements.symbols) {
            validRequirements.symbols = regexSymbol.test(password);
        }
        return validRequirements;
    };
    useEffect(() => {
        setValidRequirements(validatePassword(password, requirements));
    }, [password]);
    return {
        validRequirements,
        charactersRemainingLabel,
        requirementsArr,
        validatePassword,
    };
};
const max = (a, b) => {
    return a > b ? a : b;
};
//# sourceMappingURL=usePasswordStrengthIndicator.js.map