import Icon from "@expo/vector-icons/AntDesign";
import React, { useState } from "react";
import { View, Text, TouchableOpacity, useWindowDimensions, } from "react-native";
import Modal from "react-native-modal";
import styles from "./styles";
import { Color } from "../../constants";
import Button from "../Button";
import WizardSteps, { useWizardSteps } from "../WizardSteps";
const Wizard = ({ data, onCompletion, activeColor = Color.primary, inactiveColor = Color.lightGrey, }) => {
    const { selectedIndex, isFirstIndex, isLastIndex, titles, numberOfSteps, setSelectedIndex, onNextPress, onBackPress, } = useWizardSteps({ data, onCompletion });
    const { width } = useWindowDimensions();
    const [isHelpVisible, setIsHelpVisible] = useState(false);
    return (React.createElement(View, { style: styles.root },
        React.createElement(WizardSteps, { titles: titles, selectedIndex: selectedIndex, numberOfSteps: numberOfSteps, onStepPress: setSelectedIndex, width: width, activeColor: activeColor, inactiveColor: inactiveColor }),
        React.createElement(View, { style: styles.descriptionContainer },
            React.createElement(Text, { numberOfLines: 2, style: styles.descriptionText }, data[selectedIndex].description),
            React.createElement(TouchableOpacity, { onPress: () => setIsHelpVisible(true) },
                React.createElement(Icon, { name: "infocirlceo", size: 20, color: activeColor }))),
        React.createElement(View, { style: styles.componentContainer }, data[selectedIndex].component),
        React.createElement(View, { style: styles.buttonContainer },
            !isFirstIndex && (React.createElement(Button, { label: "BACK", onPress: onBackPress, labelColor: Color.white, backgroundColor: activeColor, style: styles.backButton })),
            React.createElement(Button, { label: isLastIndex ? "DONE" : "NEXT", onPress: onNextPress, labelColor: Color.white, backgroundColor: activeColor, style: styles.nextButton })),
        React.createElement(Modal, { isVisible: isHelpVisible, onBackdropPress: () => setIsHelpVisible(false) },
            React.createElement(View, { style: styles.modalContent },
                React.createElement(Icon, { name: "infocirlceo", size: 20, color: Color.grey }),
                !!data[selectedIndex].help && (React.createElement(Text, { style: styles.helpText }, data[selectedIndex].help))))));
};
export default Wizard;
//# sourceMappingURL=index.js.map