import Icon from "@expo/vector-icons/AntDesign";
import React from "react";
import { View, Pressable, Text, ActivityIndicator } from "react-native";
import Reanimated, { useAnimatedStyle, withDelay, withSequence, withTiming, } from "react-native-reanimated";
import styles from "./styles";
import { Color } from "../../constants";
export { useWizardSteps } from "./useWizardSteps";
const WizardSteps = ({ titles = [], selectedIndex, numberOfSteps, onStepPress, activeColor = Color.primary, inactiveColor = Color.lightGrey, showNumbers = true, processCompleted = false, showLoading = false, width, marginHorizontal = 20, }) => {
    const widthWithMargins = width - marginHorizontal * 2;
    const constantValue = 2;
    const animWidth = widthWithMargins / (numberOfSteps - 1) - constantValue;
    const animatedLineStyle = useAnimatedStyle(() => ({
        width: withTiming(animWidth * selectedIndex + 1, { duration: 600 }),
    }), [selectedIndex]);
    const pulseStyle = useAnimatedStyle(() => ({
        transform: [
            {
                scale: withDelay(300, withSequence(withTiming(1.2), withTiming(1))),
            },
        ],
    }), [selectedIndex]);
    const checkStyle = useAnimatedStyle(() => ({
        transform: [{ scale: withSequence(withTiming(1.5), withTiming(1)) }],
    }), [selectedIndex]);
    const renderSteps = () => {
        const steps = [];
        for (let i = 0; i < numberOfSteps; i++) {
            let backgroundColor = Color.white;
            const isSelected = selectedIndex === i;
            const isStepCompleted = i < selectedIndex;
            if (isStepCompleted || processCompleted) {
                backgroundColor = activeColor;
            }
            else if (isSelected) {
                backgroundColor = Color.white;
            }
            const borderColor = isSelected || isStepCompleted ? activeColor : inactiveColor;
            const circleTextColor = isSelected ? activeColor : Color.grey;
            const titleTextColor = isSelected ? activeColor : Color.grey;
            const renderInnerStepComponent = () => {
                const textColor = showNumbers && !processCompleted
                    ? circleTextColor
                    : Color.transparent;
                if (isStepCompleted || processCompleted) {
                    return (React.createElement(Reanimated.View, { style: i === selectedIndex - 1 && checkStyle },
                        React.createElement(Icon, { name: "check", size: 20, color: Color.white })));
                }
                if (showLoading && isSelected) {
                    return React.createElement(ActivityIndicator, { color: activeColor });
                }
                return (React.createElement(Text, { style: [styles.circleText, { color: textColor }] }, i + 1));
            };
            steps.push(React.createElement(Pressable, { key: i, style: styles.pressable, onPress: () => onStepPress(i) },
                React.createElement(View, { style: styles.innerPressableContainer },
                    React.createElement(Reanimated.View, { style: [
                            styles.circle,
                            { backgroundColor, borderColor },
                            isSelected && pulseStyle,
                        ] }, renderInnerStepComponent())),
                !!titles[i] && (React.createElement(View, { style: styles.spaceBetween },
                    React.createElement(Text, { numberOfLines: 2, style: [styles.titleText, { color: titleTextColor }] }, titles[i])))));
        }
        return steps;
    };
    return (React.createElement(View, { style: styles.row },
        renderSteps(),
        React.createElement(View, { style: [styles.animatedLineContainer, { width: widthWithMargins }] },
            React.createElement(Reanimated.View, { style: [
                    styles.animatedLine,
                    { backgroundColor: activeColor },
                    animatedLineStyle,
                ] }),
            React.createElement(View, { style: [styles.staticLine, { backgroundColor: inactiveColor }] }))));
};
export default WizardSteps;
//# sourceMappingURL=index.js.map